# Generated by Django 3.2.10 on 2022-01-25 11:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('galleryserve', '0002_gallery_random'),
    ]

    operations = [
        migrations.AlterField(
            model_name='gallery',
            name='height',
            field=models.IntegerField(blank=True, default=600, help_text='Height images should be resized to in pixels'),
        ),
        migrations.AlterField(
            model_name='gallery',
            name='quality',
            field=models.IntegerField(default=85, help_text='An integer between 0-100. 100 will result in the largest file size.', verbose_name='Image Quality'),
        ),
        migrations.AlterField(
            model_name='gallery',
            name='random',
            field=models.BooleanField(default=False, help_text='If selected, the sort numbers will be ignored and your gallery objects will be generated in random order.'),
        ),
        migrations.AlterField(
            model_name='gallery',
            name='resize',
            field=models.BooleanField(default=True, help_text='If selected, the dimensions specified above will be used to scale and crop the uploaded image'),
        ),
        migrations.AlterField(
            model_name='gallery',
            name='width',
            field=models.IntegerField(blank=True, default=800, help_text='Width images should be resized to in pixels'),
        ),
        migrations.AlterField(
            model_name='item',
            name='alt',
            field=models.CharField(blank=True, help_text='This will be used for the image alt attribute', max_length=100),
        ),
        migrations.AlterField(
            model_name='item',
            name='content',
            field=models.TextField(blank=True, help_text='Use this field to add html content associated with the item'),
        ),
        migrations.AlterField(
            model_name='item',
            name='credit',
            field=models.CharField(blank=True, help_text='Use this field to credit the image or content creator', max_length=200),
        ),
        migrations.AlterField(
            model_name='item',
            name='image',
            field=models.ImageField(blank=True, upload_to='galleryserve/images'),
        ),
        migrations.AlterField(
            model_name='item',
            name='sort',
            field=models.IntegerField(default=0, help_text='Items will be displayed in their sort order'),
        ),
        migrations.AlterField(
            model_name='item',
            name='title',
            field=models.CharField(blank=True, help_text='This will be used for the image or content title attribute', max_length=100),
        ),
        migrations.AlterField(
            model_name='item',
            name='url',
            field=models.CharField(blank=True, help_text='URL to which the image will be linked.', max_length=200, verbose_name='target url'),
        ),
        migrations.AlterField(
            model_name='item',
            name='video_url',
            field=models.URLField(blank=True, help_text='Enter the url of the video to be embedded', verbose_name='video url'),
        ),
    ]



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Gallery'
        db.create_table('galleryserve_gallery', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('height', self.gf('django.db.models.fields.IntegerField')(default=600, blank=True)),
            ('width', self.gf('django.db.models.fields.IntegerField')(default=800, blank=True)),
            ('resize', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('quality', self.gf('django.db.models.fields.IntegerField')(default=85)),
        ))
        db.send_create_signal('galleryserve', ['Gallery'])

        # Adding model 'Item'
        db.create_table('galleryserve_item', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('image', self.gf('django.db.models.fields.files.ImageField')(max_length=100, blank=True)),
            ('gallery', self.gf('django.db.models.fields.related.ForeignKey')(related_name='items', to=orm['galleryserve.Gallery'])),
            ('alt', self.gf('django.db.models.fields.CharField')(max_length=100, blank=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=100, blank=True)),
            ('credit', self.gf('django.db.models.fields.CharField')(max_length=200, blank=True)),
            ('video_url', self.gf('django.db.models.fields.URLField')(max_length=200, blank=True)),
            ('url', self.gf('django.db.models.fields.CharField')(max_length=200, blank=True)),
            ('content', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('sort', self.gf('django.db.models.fields.IntegerField')(default=0)),
        ))
        db.send_create_signal('galleryserve', ['Item'])


    def backwards(self, orm):
        # Deleting model 'Gallery'
        db.delete_table('galleryserve_gallery')

        # Deleting model 'Item'
        db.delete_table('galleryserve_item')


    models = {
        'galleryserve.gallery': {
            'Meta': {'ordering': "('title',)", 'object_name': 'Gallery'},
            'height': ('django.db.models.fields.IntegerField', [], {'default': '600', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'quality': ('django.db.models.fields.IntegerField', [], {'default': '85'}),
            'resize': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'width': ('django.db.models.fields.IntegerField', [], {'default': '800', 'blank': 'True'})
        },
        'galleryserve.item': {
            'Meta': {'ordering': "('sort',)", 'object_name': 'Item'},
            'alt': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'}),
            'content': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'credit': ('django.db.models.fields.CharField', [], {'max_length': '200', 'blank': 'True'}),
            'gallery': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'items'", 'to': "orm['galleryserve.Gallery']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.files.ImageField', [], {'max_length': '100', 'blank': 'True'}),
            'sort': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'}),
            'url': ('django.db.models.fields.CharField', [], {'max_length': '200', 'blank': 'True'}),
            'video_url': ('django.db.models.fields.URLField', [], {'max_length': '200', 'blank': 'True'})
        }
    }

    complete_apps = ['galleryserve']


from django.contrib import admin

from galleryserve import models
from django.conf import settings

class ItemInline(admin.StackedInline):
    model = models.Item
    extra = 1
    try:
        exclude = settings.GALLERYSERVE_EXCLUDE_FIELDS
    except:
        fieldsets = (
            (None, {'fields': (('image', 'alt', 'sort'),
            ('url', 'video_url'), ('title', 'credit'), 'content')}),
        )

class GalleryAdmin(admin.ModelAdmin):
    inlines = [
        ItemInline,
    ]
    list_display = ('title',)
    search_fields = ['title',]
    fieldsets = (
        (None, {'fields': (('title'), 'height', 'width', 'random', 'resize',
                'quality')}),
    )

admin.site.register(models.Gallery, GalleryAdmin)




# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['galleryserve',
 'galleryserve.migrations',
 'galleryserve.south_migrations',
 'galleryserve.templatetags']

package_data = \
{'': ['*']}

install_requires = \
['Pillow>=9.1.1,<10.0.0']

setup_kwargs = {
    'name': 'galleryserve',
    'version': '0.2.1',
    'description': 'Adapted from imageserve to fit broader gallery needs such as video embedding and content for controls.',
    'long_description': '# deprecate_cmsplugin_filer\nA django app for serving collections of images or videos\n\n## Dependencies:\nPillow\n\n## To install:\n    pip install galleryserve\n\nAdd \'galleryserve\' to INSTALLED_APPS\n\n## Configuration Options:\n**GALLERYSERVE_EXCLUDE_FIELDS** - This can be added as a list in your settings.py \nfile to exclude certain fields from appearing in the admin.\n\n## Template tag example:\n```\n{% load gallerytags %}\n\n{% get_gallery name %}\n{% for slide in gallery %}\n<div title="{{ slide.title }} - {{ slide.credit }}">\n{% if slide.url %}<a href="{{ slide.url }}">{% endif %}\n{% if slide.image %}<img src="{{ slide.image.url }}" alt="{{ slide.alt }}" />{% endif %}\n{% if slide.url %}</a>{% endif %}\n{% if slide.video_url %}<a href="{{ slide.video_url }}">{{ slide.title }}</a>{% endif %}\n{{ slide.title }} - {{ slide.credit }}<br />\n{{ slide.content|safe }}\n</div>\n{% endfor %}\n```\n\n## Change log:\nChanges in 0.2.0 - 05-25-22\nUpdated build process for py3 compatible app\n\nChanges in 0.1.5 - 06-27-13\nAllow for gallery title to be passed in as context variable instead of always\ntreating it as a string.\n\nChanges in 0.1.3 - 11-02-12\nMoved to git. Added ANTIALIAS to image processing\n\nChanges in 0.1.2 - 10-22-11\nFail silently on gallery not existing\n\nChanges in 0.1.1 - 9-20-11\nAdded random boolean to control whether gallery item sort should be random\npsql command to insert column:\nalter table galleryserve_gallery ADD column random boolean not null default false;\n',
    'author': 'Imagescape',
    'author_email': 'info@imagescape.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/ImaginaryLandscape/django-galleryserve',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



from django.template import Library, Node, Variable, VariableDoesNotExist
from galleryserve.models import Item, Gallery

register = Library()
	
class GalleryserveNode(Node):
    def __init__(self, gallery_name):
        self._context_variable_name = gallery_name
        self._gallery_name = Variable(gallery_name)

    def render(self, context):
        try:
            self.gallery_name = self._gallery_name.resolve(context)
        except VariableDoesNotExist:
            self.gallery_name = self._context_variable_name
         
        try:
            gallery = Gallery.objects.get(title=self.gallery_name)
            if gallery.random:
                items = Item.objects.filter(gallery__title = gallery.title).order_by('?')
            else:
                items = Item.objects.filter(gallery__title = gallery.title)
            context['gallery'] = items
            context['gallery_object'] = gallery
        except:
            pass
        return ''
          
@register.tag('get_gallery')
def get_gallery(parser, token):
    bits = token.contents.split()
    if len(bits) != 2:
        raise TemplateSyntaxError("get_gallery takes exactly 1 argument")
    return GalleryserveNode(bits[1])
